%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% This is file 'jchs.cls'
%%
%% This file is part of the Latex template for the Journal of Hydraulic and Coastal Structures.
%%
%% 2022/04/20
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{jchsmain}[2022/04/20 v0 JCHS LaTeX document class]

\newif\ifreview
\DeclareOption{review}{\reviewtrue}
\ExecuteOptions{a4paper,10pt, oneside,onecolumn,final}
\ProcessOptions
\LoadClass[10pt,a4paper]{article}
\RequirePackage[dvipsnames]{xcolor}
\RequirePackage[normalem]{ulem}
\RequirePackage{amsmath,amssymb,amsfonts,amsbsy,amsthm,setspace,epsfig,titling,authblk,xstring,lastpage,siunitx,tabularx,indentfirst,lipsum}
\RequirePackage{verbatim,graphicx,natbib,float,natbib,placeins,fancyhdr,titlesec,subfig,sectsty,lineno}
\RequirePackage{hyperref,nowidow,wrapfig}
\hypersetup{
  colorlinks   = true, %Colours links instead of ugly boxes
  urlcolor     = MidnightBlue, %Colour for external hyperlinks
  linkcolor    = MidnightBlue, %Colour of internal links
  citecolor   = black %Colour of citations
}
\urlstyle{same}
\RequirePackage[font={color=darkgray},labelfont={color=darkgray}]{caption}
\DeclareCaptionLabelSeparator{bar}{\textbar\ }
\RequirePackage[top=1.8cm, bottom=3cm, left=1.5cm, right=1.5cm]{geometry}

\setcounter{secnumdepth}{4} %% for numbering upto paragraph
 \setlength{\parindent}{10pt} %% 10pt indenting throughout the file
 \setlength{\parskip}{0.5em}
\date{}
%%%%%%%%%%%%%%%%%%%%%% font colors %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\sectionfont{\color{MidnightBlue}}
\subsectionfont{\color{MidnightBlue}}
\subsubsectionfont{\color{MidnightBlue}}
\paragraphfont{\color{MidnightBlue}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% defining new commands %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\newcommand{\journal}{Journal of Coastal and Hydraulic Structures}

\newcommand{\vol}{%
{~\number\numexpr\the\year-2020}%
}  

\newcommand{\yr}{%
{~\the\year}%
} 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% end new commands %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewenvironment{abstract}{% remove line numbers in final paper
\section*{\abstractname}%
\small
\noindent\vspace{-1.5em}%
 \setlength{\parindent}{10pt} %% 10pt indenting for abstract
 \setlength{\parskip}{0em}

 \FloatBarrier
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Side box %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\ifreview
	\AtBeginDocument \newcommand{\infobox}{%
	      \begin{wrapfigure}[\boxwrap]{r}[0pt]{0.43\textwidth}
	       \fbox{%
	 	\begin{minipage}[t]{0.41\textwidth}
		 	\vspace{0.1cm}%
		 
		 \begin{flushleft}
			\ifreview
			{Author information hidden in double blind review}\par 
			\else
			\small {\AB@affillist{}}%
			\fi
			 \end{flushleft}
			\vspace{0.25cm}
	\small {This paper was submitted on \submitted. It was accepted after double-blind review on \mbox{\accepted} and published online on \mbox{\online}.}
	\vspace{0.1cm} \hrule \vspace{0.5cm}
	\ifreview		 
		 \small \textcolor{black}{DOI:\href{https://doi.org/\adoi}{\uline{\adoi}}  \vspace{0.3cm}\\
	 		\noindent Cite as: Author list hidden in double blind review, \@title, \journal, \art, DOI: \adoi   } \\
		\vspace{0.5cm} \hrule \vspace{0.1cm} 
		\else
		 \small \textcolor{black}{DOI: \href{https://doi.org/\adoi}{\uline{\adoi}}  \vspace{0.3cm} \\
	 		\noindent Cite as: \citeas, \@title, \journal, \art, DOI: \adoi } \\
							\vspace{0.1cm} \hrule \vspace{0.1cm} 
		\fi
  	\small{The Journal of Coastal and Hydraulic Structures is a community-based, free, and open access journal for the dissemination of high-quality knowledge on the engineering science of coastal and hydraulic structures. This paper has been written and reviewed with care. However, the authors and the journal do not accept any liability which might arise from use of its contents. Copyright \copyright \yr\  by the authors. This journal paper is published under a CC BY 4.0 license, which allows anyone to redistribute, mix and adapt, as long as credit is given to the authors.}
	\includegraphics[width=0.13\textwidth]{logocc.jpg}%
	\end{minipage}
	}%
	\end{wrapfigure}
	}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Setting headers and footers %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\pagestyle{fancy}
\lhead{\includegraphics[scale=0.55]{logojchs.pdf}} 
\rhead{\includegraphics[scale=0.12]{logotud.pdf}}
\setlength{\headsep}{16pt}
\ifreview                                             
	\chead{Author undisclosed}  
\else
	\chead{\leadauthor\ et. al.}%{{\leadauthor} et al., {\yr} } Author, F. et. al.
\fi
\lfoot{\footnotesize{\journal\ Vol.~\vol, \yr, Paper \art}}                                               
\cfoot{}
\rfoot{\footnotesize{\thepage\ of \pageref*{LastPage}}}
\renewcommand{\headrulewidth}{0.25pt}
\renewcommand{\footrulewidth}{0.25pt}
\setlength{\headheight}{36pt}

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% End headers and footers %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Titlepage %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\fancypagestyle{first}%
	{\fancyhf{}
	\setlength{\headheight}{36pt}%
	\renewcommand{\headrulewidth}{0.25pt}%
	\fancyhead[L]{\includegraphics[scale=0.55]{logojchs.pdf}}%
	\fancyhead[R]{\includegraphics[scale=0.12]{logotud.pdf}}%
	\fancyfoot[L]{\journal\ Vol.~\vol, \yr, Paper \art}
	\fancyfoot[R]{ \thepage\ of\ \pageref*{LastPage}}
	}%

%\if@titlepage
\renewcommand{\maketitle} {%
		  \let\footnotesize\small
  	\let\footnoterule\relax
  	\let \footnote \thanks
		\thispagestyle{first}%
		\headsep=37pt
		\begin{center}
		\Large \textbf{JOURNAL OF COASTAL AND HYDRAULIC STRUCTURES}\par%
			\bigskip
		\small{\textit{Vol.}\vol,\yr, \art}\par%
		\vspace{1.0cm}
		\hrule
		\bigskip
     		\end{center}%
		{\LARGE \textbf {\@title} \par}%
		\bigskip
		\ifreview
		{Double blind review}\par \vspace{0.25cm}%
		\else
		 \AB@authlist{}\par \vspace{0.25cm}%%	 
		 \fi		

}%
\captionsetup{justification=raggedright,singlelinecheck=false,labelsep=bar} %%left aligned captions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% End Titlepage %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




 



%%%%%% %%%%%%%%%%%%%%%%%%%%%%%%review format%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\ifreview
	\linenumbers%
\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%end of review format %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%






%%%\renewcommand{\footnoterule}{%
%%  \kern -3pt
  %%\hrule width \textwidth                 
%%\kern 2.6pt
%%}




\endinput